@@ -352,7 +352,7 @@ def __save_database_profile(profile_js, layer, spark=None):
     if spark is None:
         spark = get_spark_session("upsert_data")
 
-    profile_js = json.dumps(profile_js["profilling"]["descriptiveStatistics"]["fields"])
+    profile_js = profile_js["profilling"]["descriptiveStatistics"]["fields"]
     df = spark.createDataFrame(profile_js)
     df.write.option("header", "true").format('delta').mode('append').option("mergeSchema", "true").saveAsTable(table)
 
